#include "RcppMLPACK.h"

using namespace mlpack::kmeans;
using namespace Rcpp;

// [[Rcpp::export]]
List kmeans(const arma::mat& data, const int& clusters) {
    
    arma::Col<long> assignments;

	// Initialize with the default arguments.
	KMeans<> k;

	k.Cluster(data, clusters, assignments); 

    return List::create(_["clusters"]	= clusters,
                        _["result"]		= assignments);
}
